'use strict';

const vscode = require('./vscode.cjs');
require('jszip');
require('ofetch');
require('resolve-pathname');
require('json5');

function vscodeTheme2MonacoTheme(vscodeTheme) {
  const base = vscode.isDarkTheme(vscodeTheme) ? "vs-dark" : "vs";
  const rules = vscodeTheme.tokenColors.map((token) => {
    const scopes = typeof token.scope === "string" ? token.scope.split(",") : token.scope || [];
    const foreground = token.settings?.foreground && vscode.normalizeHexColor(token.settings.foreground).slice(1);
    const background = token.settings?.background && vscode.normalizeHexColor(token.settings.background).slice(1);
    return scopes.map((scope) => ({
      ...token.settings,
      foreground,
      background,
      token: scope
    }));
  }).flat();
  const colors = vscodeTheme.colors || {};
  return {
    base,
    inherit: true,
    colors,
    rules,
    encodedTokensColors: []
  };
}
async function loadMonacoThemeFromVSCodeTheme(vscodeThemeId) {
  const themeJSON = await vscode.downloadVSCodeTheme(vscodeThemeId);
  const monacoThemeJSON = vscodeTheme2MonacoTheme(themeJSON);
  return monacoThemeJSON;
}

exports.loadMonacoThemeFromVSCodeTheme = loadMonacoThemeFromVSCodeTheme;
exports.vscodeTheme2MonacoTheme = vscodeTheme2MonacoTheme;
