import { d as VSCodeTheme, c as VSCodeThemeId } from './types-6c45dfe8.js';

/**
 * Convert VS Code theme to monaco editor theme.
 *
 * vscode theme(monaco based on it): https://github.com/microsoft/vscode/blob/784e72bc4486b7ea5ad3447c506e31d949848592/src/vs/editor/standalone/common/themes.ts#L11
 * monaco editro full theme tokens: https://github.com/microsoft/monaco-editor/blob/0c6348a71d02351ad7d5c3ac2660cb19902c919d/website/src/website/data/playground-samples/customizing-the-appearence/exposed-colors/sample.js#L8
 * @param vscodeTheme
 * @returns monaco.editor.IStandaloneThemeData
 */
declare function vscodeTheme2MonacoTheme(vscodeTheme: VSCodeTheme): {
    base: string;
    inherit: boolean;
    colors: {
        'editor.foreground'?: string | undefined;
        'editor.background'?: string | undefined;
    };
    rules: {
        foreground: string | undefined;
        background: string | undefined;
        token: string;
        fontStyle?: string | undefined;
    }[];
    encodedTokensColors: never[];
};
/**
 * Download VS Code theme and convert to monaco theme online.
 */
declare function loadMonacoThemeFromVSCodeTheme(vscodeThemeId: VSCodeThemeId): Promise<{
    base: string;
    inherit: boolean;
    colors: {
        'editor.foreground'?: string | undefined;
        'editor.background'?: string | undefined;
    };
    rules: {
        foreground: string | undefined;
        background: string | undefined;
        token: string;
        fontStyle?: string | undefined;
    }[];
    encodedTokensColors: never[];
}>;

export { loadMonacoThemeFromVSCodeTheme, vscodeTheme2MonacoTheme };
