import { isDarkTheme, normalizeHexColor, downloadVSCodeTheme } from './vscode.mjs';
import 'jszip';
import 'ofetch';
import 'resolve-pathname';
import 'json5';

function vscodeTheme2MonacoTheme(vscodeTheme) {
  const base = isDarkTheme(vscodeTheme) ? "vs-dark" : "vs";
  const rules = vscodeTheme.tokenColors.map((token) => {
    const scopes = typeof token.scope === "string" ? token.scope.split(",") : token.scope || [];
    const foreground = token.settings?.foreground && normalizeHexColor(token.settings.foreground).slice(1);
    const background = token.settings?.background && normalizeHexColor(token.settings.background).slice(1);
    return scopes.map((scope) => ({
      ...token.settings,
      foreground,
      background,
      token: scope
    }));
  }).flat();
  const colors = vscodeTheme.colors || {};
  return {
    base,
    inherit: true,
    colors,
    rules,
    encodedTokensColors: []
  };
}
async function loadMonacoThemeFromVSCodeTheme(vscodeThemeId) {
  const themeJSON = await downloadVSCodeTheme(vscodeThemeId);
  const monacoThemeJSON = vscodeTheme2MonacoTheme(themeJSON);
  return monacoThemeJSON;
}

export { loadMonacoThemeFromVSCodeTheme, vscodeTheme2MonacoTheme };
