import { c as VSCodeThemeId, d as VSCodeTheme, S as SelectorScope, V as VSCodeThemeTokenScope, a as VSCodeThemeTokenSettings } from './types-6c45dfe8.js';

/**
 * Download theme from VS Code market.
 * `<Identifier>.<ThemeName>`
 * .Eg. `kricsleo.gentle-clen.Gentle Clean Vitesse`
 */
declare function downloadVSCodeTheme(vscodeThemeId: VSCodeThemeId): Promise<any>;
declare function isDarkTheme(vscodeTheme: VSCodeTheme): boolean;
declare function isDarkColor(color: string): boolean;
declare function normalizeHexColor(color: string): string;
declare function normalizeThemeName(name: string): string;
declare function getThemeStyle(selectorScope: SelectorScope, theme: VSCodeTheme): string;
/**
 * todo: using tokenColors.[global settting] (no scope specified)
 * with colors.editor.foreground & colors.editor.background
 */
declare function getVSCodeScopeStyle(scope: string, theme: VSCodeTheme): string | null;
declare function scoreScopeMatch(sourceScope: string, targetScope: VSCodeThemeTokenScope): number;
declare function getVSCodeTokenStyle(settings: VSCodeThemeTokenSettings): string | null;
/**
 * https://github.com/microsoft/vscode/blob/f7f05dee53fb33fe023db2e06e30a89d3094488f/src/vs/platform/theme/common/colorRegistry.ts#L258-L268
 */
declare const VSCODE_FALLBACK_EDITOR_FG: {
    light: string;
    dark: string;
};
declare const VSCODE_FALLBACK_EDITOR_BG: {
    light: string;
    dark: string;
};
/**
 * Forked from shiki
 * https://github.com/shikijs/shiki/blob/db5c62bda448a3c95c66b9cc0b4980b8df856a58/packages/shiki/src/loader.ts#L208
 */
declare function getDefaultThemeSetting(theme: VSCodeTheme): {
    foreground: string;
    background: string;
};

export { VSCODE_FALLBACK_EDITOR_BG, VSCODE_FALLBACK_EDITOR_FG, downloadVSCodeTheme, getDefaultThemeSetting, getThemeStyle, getVSCodeScopeStyle, getVSCodeTokenStyle, isDarkColor, isDarkTheme, normalizeHexColor, normalizeThemeName, scoreScopeMatch };
